@@ -26,6 +26,7 @@ my @Scalar_Flags = qw(
 		      reverse
 		      adjusted
 		      has_non_adjusted
+                      env_proxy
 		      debug
 		     );
 my $SF_pat = join('|', @Scalar_Flags);
@@ -84,6 +85,7 @@ sub new {
   bless $self, $class;
 
   $self->{ua} = new LWP::UserAgent;
+  $self->{ua}->env_proxy() if $parms{env_proxy};
   $self->start_date($start_date);
   $self->end_date($end_date);
   $self->symbols(@$symbols);
@@ -661,7 +663,8 @@ sub number_normalize {
   my $labelmap = $self->target_label_map;
   foreach my $row (@$rows) {
     foreach (grep(!/date/i, keys %$labelmap)) {
-      next unless defined $labelmap->{$_};
+      # Hedge against nonexistant header columns
+      next unless defined $labelmap->{$_} && defined $row->[$labelmap->{$_}];
       $row->[$labelmap->{$_}] =~ s/[^\d\.]//go;
     }
   }
@@ -678,11 +681,13 @@ sub precision_normalize {
   my $labelmap = $self->target_label_map;
   foreach my $row (@$rows) {
     foreach (qw(open high low close adj)) {
-      next unless defined $labelmap->{$_};
+      next unless defined $labelmap->{$_} && defined $row->[$labelmap->{$_}];
       $row->[$labelmap->{$_}] = sprintf("%.$self->{quote_precision}f",
 					$row->[$labelmap->{$_}]);
     }
-    $row->[$labelmap->{vol}] = sprintf("%d", $row->[$labelmap->{vol}]);
+    # Hedge against nonexistant vol column
+    $row->[$labelmap->{vol}] = sprintf("%d", $row->[$labelmap->{vol}])
+      if defined $labelmap->{vol} && $#{$row} >= $labelmap->{vol};
   }
   $rows;
 }
@@ -827,9 +832,9 @@ sub html_table_parser {
   my($self, $html_string, @column_labels) = @_;
   if (!@column_labels) {
     my $lmethod = $self->labels_method;
-    print STDERR "Lables generated by $lmethod: ";
     @column_labels = $self->$lmethod();
-    print STDERR join('|', @column_labels),"\n";
+    print STDERR "Labels generated by $lmethod: ", join('|', @column_labels),"\n"
+      if $self->{verbose};
   }
   my $te = HTML::TableExtract->new(
 				   headers => \@column_labels,
@@ -876,7 +881,8 @@ sub csv_parser {
   # taking a slice of the label map, unrequested columns are
   # eliminated.
   my $dlm = $self->label_map(@column_labels);
-  my @ordered_lkeys = sort { $dlm->{$a} <=> $dlm->{$b} } keys %$dlm;
+  # Hedge against nonexistant header columns
+  my @ordered_lkeys = grep(exists $label_map->{$_}, sort { $dlm->{$a} <=> $dlm->{$b} } keys %$dlm);
   my @reordered_label_indicies = @{$label_map}{@ordered_lkeys};
 
   # We have to generate the pattern for each batch because Yahoo uses
@@ -1107,7 +1113,7 @@ Finance::QuoteHist::Generic - Base class for retrieving historical stock quotes.
     # This method should return the set of URLs necessary to extract
     # the quotes from this particular site given the list of symbols
     # and date range provided during instantiation. See
-    # Finance::QuoteHist::MotleyFool for a basic example of how to do
+    # Finance::QuoteHist::SiliconInvestor for a basic example of how to do
     # this, or Finance::QuoteHist::Yahoo for a more complicated
     # example.
   }
@@ -1126,8 +1132,8 @@ particular, the C<quote_urls()> method should be overridden, and
 provide however many URLs are necessary to retrieve the data over a
 list of symbols within the given date range.  Different sites have
 different limitations on how many quotes are returned for each
-query. See Finance::QuoteHist::MotleyFool,
-Finance::QuoteHist::FinancialWeb, and Finance::QuoteHist::Yahoo for
+query. See Finance::QuoteHist::WallStreetCity,
+Finance::QuoteHist::SiliconInvestor, and Finance::QuoteHist::Yahoo for
 some examples of how to do this.
 
 For more complicated sites, such as Yahoo, more methods are available
@@ -1206,6 +1212,12 @@ this to 0 will disable the rounding behavior, returning the quote
 values as they appear on the sites (assuming no auto-adjustment has
 taken place). The default is 4.
 
+=item env_proxy
+
+When set, instructs the underlying LWP::UserAgent to load proxy
+configuration information from environment variables. See
+the C<ua()> method and L<LWP::UserAgent> for more information.
+
 =item verbose
 
 When set, many status messages are printed to STDERR indicating
@@ -1370,7 +1382,18 @@ slight variations across sites.
 =item ua()
 
 Accessor method for the LWP::UserAgent object used to process
-HTTP::Request for individual URLs.
+HTTP::Request for individual URLs. This can be handy for such
+things as configuring proxy access for the underlying user
+agent. Example:
+
+ # Manual configuration
+ $qh1->ua->proxy(['http'], 'http://proxy.sn.no:8001/');
+
+ # Load from environment variables
+ $qh2->ua->env_proxy();
+
+See L<LWP::UserAgent> for more information on the capabilities
+of that module.
 
 =back
 
@@ -1477,7 +1500,7 @@ Matthew P. Sisk, E<lt>F<sisk@mojotoad.com>E<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2000 Matthew P. Sisk.  All rights reserved. All wrongs
+Copyright (c) 2000-2002 Matthew P. Sisk.  All rights reserved. All wrongs
 revenged. This program is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
 
